The duckplyr package relies on a DBI connection to an in-memory database.
The db_exec() function allows running SQL statements with side effects on this connection.
It can be used to execute statements that start with PRAGMA, SET, or ATTACH
to, e.g., set up credentials, change configuration options, or attach other databases.
See https://duckdb.org/docs/configuration/overview.html for more information on the configuration options,
and https://duckdb.org/docs/sql/statements/attach.html for attaching databases.
Value
The return value of the DBI::dbExecute() call, invisibly.