last_rel: Retrieve details about the most recent computation

View source: R/last.R

last_relR Documentation

Retrieve details about the most recent computation

Description

Before a result is computed, it is specified as a "relation" object. This function retrieves this object for the last computation that led to the materialization of a data frame.

Usage

last_rel()

Value

A duckdb "relation" object, or NULL if no computation has been performed yet.


duckplyr documentation built on March 10, 2026, 9:06 a.m.