unsupported: Verbs not implemented in duckplyr

unsupportedR Documentation

Verbs not implemented in duckplyr

Description

The following dplyr generics have no counterpart method in duckplyr. If you want to help add a new verb, please refer to our contributing guide https://duckplyr.tidyverse.org/CONTRIBUTING.html#support-new-verbs

Unsupported verbs

For these verbs, duckplyr will fall back to dplyr.

  • add_count()

  • cross_join()

  • do()

  • group_by()

  • group_indices()

  • group_keys()

  • group_map()

  • group_modify()

  • group_nest()

  • group_size()

  • group_split()

  • group_trim()

  • groups()

  • n_groups()

  • nest_by()

  • nest_join()

  • reframe()

  • rename_with()

  • rows_append()

  • rows_delete()

  • rows_insert()

  • rows_patch()

  • rows_update()

  • rows_upsert()

  • rowwise()

  • setequal()

  • slice_sample()

  • slice_tail()

  • slice()

  • ungroup()


duckplyr documentation built on March 10, 2026, 9:06 a.m.