This is a generic function that executes a query
and stores the results in a CSV file.
For a duckplyr frame, the materialization occurs outside of R.
The result is a duckplyr frame that can be used with subsequent dplyr verbs.
A data frame (the class may vary based on the input).
Arguments
x
A data frame or lazy data frame.
path
The path of the CSV file to create.
...
Additional arguments passed to methods.
prudence
Memory protection, controls if DuckDB may convert
intermediate results in DuckDB-managed memory to data frames in R memory.
"lavish": regardless of size,
"stingy": never,
"thrifty": up to a maximum size of 1 million cells.
The default is to inherit from the input.
This argument is provided here only for convenience.
The same effect can be achieved by forwarding the output to as_duckdb_tibble()
with the desired prudence.
See vignette("prudence") for more information.